/// <reference types="node" />
import { EventEmitter } from "events";
import AuthTokens from "../types/AuthTokens";
import DeviceId from "../types/DeviceId";
import MqttConnection from "./MqttConnection";
import MqttMessage from "./MqttMessage";
import MqttPacket from "./MqttPacket";
/**
 * Handles decoding and sending all sorts of messages used by Facebook Messenger.
 * It utilizes all network primitives defined in the MqttConnection class.
 */
export default class MqttApi extends EventEmitter {
    connection: MqttConnection;
    lastMsgId: number;
    tokens: AuthTokens;
    lastPingMilis: number;
    deviceId: DeviceId;
    constructor();
    sendSubscribe(msg: MqttMessage): Promise<number | void>;
    /**
     * Connects the MQTT socket and binds listeners for receiving messages.
     * @param tokens
     * @param deviceId
     */
    connect(tokens: AuthTokens, deviceId: DeviceId): Promise<void>;
    reconnect: () => Promise<void>;
    sendPing: () => void;
    /**
     * Sends a CONNECT mqtt message
     */
    sendConnectMessage(): Promise<void>;
    sendPublish(topic: string, data: string): Promise<number | void>;
    /**
     * Sends a facebook messenger message to someone.
     */
    sendMessage(threadId: string, message: string): Promise<{}>;
    sendPublishConfirmation(flags: number, publish: any): Promise<void>;
    parsePacket: (packet: MqttPacket) => Promise<void>;
}
